@@ -1,12 +1,18 @@
 magcon <-
 function(x,y,h,doim=TRUE,docon=TRUE,dobar=TRUE,n=100,add=FALSE,xlab='',ylab='',imcol=rev(rainbow(1000,start=0,end=2/3)),conlevels=c(0.5,pnorm(1)-pnorm(-1),0.95), barposition='topright', barorient='v',bartitle='Contained %',bartitleshift=0,xlim=NULL,ylim=NULL,weights=NA,...){
+ngrid=n*2
+if(missing(y)){
+  if(!is.null(dim(x))){
+    if(dim(x)[2]>=2){y=x[,2];x=x[,1]}
+  }
+}
 if(is.null(xlim)){xlim=range(x,na.rm=TRUE)}
 if(is.null(ylim)){ylim=range(y,na.rm=TRUE)}
 use=x>=min(xlim) & x<=max(xlim) & y>=min(ylim) & y<=max(ylim)
 if(is.na(weights[1])==FALSE & length(weights)==length(x)){weights=weights[use]}
 x=x[use];y=y[use]
 conlevels=1-conlevels
-tempcon=sm.density(cbind(x,y),h=h,weights=weights,display='none',ngrid=n)
+tempcon=sm.density(cbind(x,y),h=h,weights=weights,display='none',ngrid=ngrid,xlim=xlim+c(-diff(xlim),diff(xlim)),ylim=ylim+c(-diff(ylim),diff(ylim)))
 tempcon$x=tempcon$eval.points[,1]
 tempcon$y=tempcon$eval.points[,2]
 tempcon$z=tempcon$estimate
@@ -14,7 +20,7 @@ temp=sort(tempcon$z)
 tempsum=cumsum(temp)
 convfunc=approxfun(tempsum,temp)
 levelmap=approxfun(convfunc(seq(0,1,len=1000)*max(tempsum)),seq(0,1,len=1000))
-tempcon$z=matrix(levelmap(tempcon$z),nrow=n)
+tempcon$z=matrix(levelmap(tempcon$z),nrow=ngrid)
 tempcon$z[is.na(tempcon$z)]=min(tempcon$z,na.rm=TRUE)
 if(doim){
   if(add==FALSE){
